EntryPart

Struct EntryPart 

pub struct EntryPart<T = Vec<u8>>(/* private fields */);
👎Deprecated since 0.38.0:

use Archive::write_split_header instead

A structure representing the split Entry for archive splitting.

Implementations

Source

impl<T> EntryPart<T>
where RawChunk<T>: Chunk,

pub fn bytes_len(&self) -> usize

Returns the total length of this entry part in bytes.

Source

impl EntryPart<&[u8]>

pub fn try_split( self, max_bytes_len: usize, ) -> Result<(EntryPart<&[u8]>, Option<EntryPart<&[u8]>>), EntryPart<&[u8]>>

Splits this EntryPart into two parts if its length exceeds the given value.

Errors

If it can’t split into smaller than the given value, it returns an error containing the original value.