Metadata

Struct Metadata 

pub struct Metadata { /* private fields */ }
Metadata information about an entry.

Examples

use libpna::{Duration, Metadata};

let since_unix_epoch = Duration::seconds(1000);
let metadata = Metadata::new()
    .with_accessed(Some(since_unix_epoch))
    .with_created(Some(since_unix_epoch))
    .with_modified(Some(since_unix_epoch));

Implementations

Source

impl Metadata

pub const fn new() -> Metadata

Creates a new Metadata.

pub const fn with_created(self, created: Option<Duration>) -> Metadata

Sets the created time as the duration since the Unix epoch.

Examples
use libpna::{Duration, Metadata};

let since_unix_epoch = Duration::seconds(1000);
let metadata = Metadata::new().with_created(Some(since_unix_epoch));
pub const fn with_modified(self, modified: Option<Duration>) -> Metadata

Sets the modified time as the duration since the Unix epoch.

Examples
use libpna::{Duration, Metadata};

let since_unix_epoch = Duration::seconds(1000);
let metadata = Metadata::new().with_modified(Some(since_unix_epoch));
pub const fn with_accessed(self, accessed: Option<Duration>) -> Metadata

Sets the accessed time as the duration since the Unix epoch.

Examples
use libpna::{Duration, Metadata};

let since_unix_epoch = Duration::seconds(1000);
let metadata = Metadata::new().with_accessed(Some(since_unix_epoch));
pub fn with_permission(self, permission: Option<Permission>) -> Metadata

👎Deprecated since 0.34.0:

the fPRM chunk is superseded by the owner facet chunks; use Metadata::with_owner_uid/with_owner_gid/with_owner_user_name/with_owner_group_name/with_owner_user_sid/with_owner_group_sid/with_permission_mode

Sets the permission of the entry.

pub fn with_owner_uid(self, value: Option<OwnerUid>) -> Metadata

Sets the owner user id facet (fUId).

pub fn with_owner_gid(self, value: Option<OwnerGid>) -> Metadata

Sets the owner group id facet (fGId).

pub fn with_owner_user_name(self, value: Option<OwnerUserName>) -> Metadata

Sets the owner user name facet (fONm).

pub fn with_owner_group_name(self, value: Option<OwnerGroupName>) -> Metadata

Sets the owner group name facet (fGNm).

pub fn with_owner_user_sid(self, value: Option<OwnerUserSid>) -> Metadata

Sets the owner user SID facet (fOSi).

pub fn with_owner_group_sid(self, value: Option<OwnerGroupSid>) -> Metadata

Sets the owner group SID facet (fGSi).

pub fn with_permission_mode(self, value: Option<PermissionMode>) -> Metadata

Sets the POSIX permission mode facet (fMOd).

Sets the link target type of the entry. Only meaningful for symbolic link and hard link entries.

pub fn with_xattrs(self, xattrs: impl Into<Vec<ExtendedAttribute>>) -> Metadata

Sets the extended attributes facet (xATR).

Each attribute is serialized as one xATR chunk. Passing an empty collection records no attributes and emits no xATR chunks.

pub const fn raw_file_size(&self) -> Option<u128>

Returns the raw file size of this entry’s data in bytes.

pub const fn compressed_size(&self) -> usize

Returns the compressed size of this entry’s data in bytes.

pub const fn created(&self) -> Option<Duration>

Returns the created time since the Unix epoch for the entry.

pub const fn modified(&self) -> Option<Duration>

Returns the modified time since the Unix epoch for the entry.

pub const fn accessed(&self) -> Option<Duration>

Returns the accessed time since the Unix epoch for the entry.

pub const fn permission(&self) -> Option<&Permission>

👎Deprecated since 0.34.0:

the fPRM chunk is superseded by the owner facet chunks; use Metadata::owner_uid/owner_gid/owner_user_name/owner_group_name/owner_user_sid/owner_group_sid/permission_mode

Returns the owner, group, and permission bits for the entry.

pub const fn owner_uid(&self) -> Option<OwnerUid>

Returns the owner user id facet (fUId), if recorded.

pub const fn owner_gid(&self) -> Option<OwnerGid>

Returns the owner group id facet (fGId), if recorded.

pub fn owner_user_name(&self) -> Option<&OwnerUserName>

Returns the owner user name facet (fONm), if recorded.

pub fn owner_group_name(&self) -> Option<&OwnerGroupName>

Returns the owner group name facet (fGNm), if recorded.

pub fn owner_user_sid(&self) -> Option<&OwnerUserSid>

Returns the owner user SID facet (fOSi), if recorded.

pub fn owner_group_sid(&self) -> Option<&OwnerGroupSid>

Returns the owner group SID facet (fGSi), if recorded.

pub const fn permission_mode(&self) -> Option<PermissionMode>

Returns the POSIX permission mode facet (fMOd), if recorded.

Returns the link target type for this entry, if present.

  • None: fLTP chunk was absent.
  • Some(Unknown): fLTP chunk present but target type undetermined.
  • Some(File) / Some(Directory): known target type.
pub fn xattrs(&self) -> &[ExtendedAttribute]

Returns the extended attributes (xATR) recorded for this entry.