pub struct Metadata { /* private fields */ }Expand description
Metadata information about an entry.
Examples
use libpna::{Duration, Metadata};
let since_unix_epoch = Duration::seconds(1000);
let metadata = Metadata::new()
.with_accessed(Some(since_unix_epoch))
.with_created(Some(since_unix_epoch))
.with_modified(Some(since_unix_epoch));Implementations
Sourceimpl Metadata
impl Metadata
Sourcepub const fn with_created(self, created: Option<Duration>) -> Metadata
pub const fn with_created(self, created: Option<Duration>) -> Metadata
Sets the created time as the duration since the Unix epoch.
Examples
use libpna::{Duration, Metadata};
let since_unix_epoch = Duration::seconds(1000);
let metadata = Metadata::new().with_created(Some(since_unix_epoch));Sourcepub const fn with_modified(self, modified: Option<Duration>) -> Metadata
pub const fn with_modified(self, modified: Option<Duration>) -> Metadata
Sets the modified time as the duration since the Unix epoch.
Examples
use libpna::{Duration, Metadata};
let since_unix_epoch = Duration::seconds(1000);
let metadata = Metadata::new().with_modified(Some(since_unix_epoch));Sourcepub const fn with_accessed(self, accessed: Option<Duration>) -> Metadata
pub const fn with_accessed(self, accessed: Option<Duration>) -> Metadata
Sets the accessed time as the duration since the Unix epoch.
Examples
use libpna::{Duration, Metadata};
let since_unix_epoch = Duration::seconds(1000);
let metadata = Metadata::new().with_accessed(Some(since_unix_epoch));Sourcepub fn with_permission(self, permission: Option<Permission>) -> Metadata
👎Deprecated since 0.34.0: the fPRM chunk is superseded by the owner facet chunks; use Metadata::with_owner_uid/with_owner_gid/with_owner_user_name/with_owner_group_name/with_owner_user_sid/with_owner_group_sid/with_permission_mode
pub fn with_permission(self, permission: Option<Permission>) -> Metadata
the fPRM chunk is superseded by the owner facet chunks; use Metadata::with_owner_uid/with_owner_gid/with_owner_user_name/with_owner_group_name/with_owner_user_sid/with_owner_group_sid/with_permission_mode
Sets the permission of the entry.
Sourcepub fn with_owner_uid(self, value: Option<OwnerUid>) -> Metadata
pub fn with_owner_uid(self, value: Option<OwnerUid>) -> Metadata
Sets the owner user id facet (fUId).
Sourcepub fn with_owner_gid(self, value: Option<OwnerGid>) -> Metadata
pub fn with_owner_gid(self, value: Option<OwnerGid>) -> Metadata
Sets the owner group id facet (fGId).
Sourcepub fn with_owner_user_name(self, value: Option<OwnerUserName>) -> Metadata
pub fn with_owner_user_name(self, value: Option<OwnerUserName>) -> Metadata
Sets the owner user name facet (fONm).
Sourcepub fn with_owner_group_name(self, value: Option<OwnerGroupName>) -> Metadata
pub fn with_owner_group_name(self, value: Option<OwnerGroupName>) -> Metadata
Sets the owner group name facet (fGNm).
Sourcepub fn with_owner_user_sid(self, value: Option<OwnerUserSid>) -> Metadata
pub fn with_owner_user_sid(self, value: Option<OwnerUserSid>) -> Metadata
Sets the owner user SID facet (fOSi).
Sourcepub fn with_owner_group_sid(self, value: Option<OwnerGroupSid>) -> Metadata
pub fn with_owner_group_sid(self, value: Option<OwnerGroupSid>) -> Metadata
Sets the owner group SID facet (fGSi).
Sourcepub fn with_permission_mode(self, value: Option<PermissionMode>) -> Metadata
pub fn with_permission_mode(self, value: Option<PermissionMode>) -> Metadata
Sets the POSIX permission mode facet (fMOd).
Sourcepub const fn with_link_target_type(
self,
link_target_type: Option<LinkTargetType>,
) -> Metadata
pub const fn with_link_target_type( self, link_target_type: Option<LinkTargetType>, ) -> Metadata
Sets the link target type of the entry. Only meaningful for symbolic link and hard link entries.
Sourcepub const fn raw_file_size(&self) -> Option<u128>
pub const fn raw_file_size(&self) -> Option<u128>
Returns the raw file size of this entry’s data in bytes.
Sourcepub const fn compressed_size(&self) -> usize
pub const fn compressed_size(&self) -> usize
Returns the compressed size of this entry’s data in bytes.
Sourcepub const fn created(&self) -> Option<Duration>
pub const fn created(&self) -> Option<Duration>
Returns the created time since the Unix epoch for the entry.
Sourcepub const fn modified(&self) -> Option<Duration>
pub const fn modified(&self) -> Option<Duration>
Returns the modified time since the Unix epoch for the entry.
Sourcepub const fn accessed(&self) -> Option<Duration>
pub const fn accessed(&self) -> Option<Duration>
Returns the accessed time since the Unix epoch for the entry.
Sourcepub const fn permission(&self) -> Option<&Permission>
👎Deprecated since 0.34.0: the fPRM chunk is superseded by the owner facet chunks; use Metadata::owner_uid/owner_gid/owner_user_name/owner_group_name/owner_user_sid/owner_group_sid/permission_mode
pub const fn permission(&self) -> Option<&Permission>
the fPRM chunk is superseded by the owner facet chunks; use Metadata::owner_uid/owner_gid/owner_user_name/owner_group_name/owner_user_sid/owner_group_sid/permission_mode
Returns the owner, group, and permission bits for the entry.
Sourcepub const fn owner_uid(&self) -> Option<OwnerUid>
pub const fn owner_uid(&self) -> Option<OwnerUid>
Returns the owner user id facet (fUId), if recorded.
Sourcepub const fn owner_gid(&self) -> Option<OwnerGid>
pub const fn owner_gid(&self) -> Option<OwnerGid>
Returns the owner group id facet (fGId), if recorded.
Sourcepub fn owner_user_name(&self) -> Option<&OwnerUserName>
pub fn owner_user_name(&self) -> Option<&OwnerUserName>
Returns the owner user name facet (fONm), if recorded.
Sourcepub fn owner_group_name(&self) -> Option<&OwnerGroupName>
pub fn owner_group_name(&self) -> Option<&OwnerGroupName>
Returns the owner group name facet (fGNm), if recorded.
Sourcepub fn owner_user_sid(&self) -> Option<&OwnerUserSid>
pub fn owner_user_sid(&self) -> Option<&OwnerUserSid>
Returns the owner user SID facet (fOSi), if recorded.
Sourcepub fn owner_group_sid(&self) -> Option<&OwnerGroupSid>
pub fn owner_group_sid(&self) -> Option<&OwnerGroupSid>
Returns the owner group SID facet (fGSi), if recorded.
Sourcepub const fn permission_mode(&self) -> Option<PermissionMode>
pub const fn permission_mode(&self) -> Option<PermissionMode>
Returns the POSIX permission mode facet (fMOd), if recorded.
Sourcepub const fn link_target_type(&self) -> Option<LinkTargetType>
pub const fn link_target_type(&self) -> Option<LinkTargetType>
Returns the link target type for this entry, if present.
None: fLTP chunk was absent.Some(Unknown): fLTP chunk present but target type undetermined.Some(File)/Some(Directory): known target type.